@@ -1,6 +1,6 @@
 /*
- * (c) 2007-2008, Robert Schilling
- *                Bernhard Walle <bernhard.walle@gmx.de>
+ * (c) 2007-2010, Robert Schilling
+ *                Bernhard Walle <bernhard@bwalle.de>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,7 @@ class usbprogFrm : public wxFrame {
         void deleteCache(wxCommandEvent &evt);
         void exitMenuHandler(wxCommandEvent &evt);
         void aboutMenuHandler(wxCommandEvent &evt);
+        void helpDocumentHandler(wxCommandEvent &evt);
         void deviceComboHandler(wxCommandEvent &evt);
         void deviceRefreshHandler(wxCommandEvent &evt);
         void firmwareRefreshHandler(wxCommandEvent &evt);
@@ -111,6 +112,7 @@ class usbprogFrm : public wxFrame {
             ID_PROCESS_GAUGE,
             ID_COPYRIGHT_LABEL,
             ID_EXIT_MENU,
+            ID_SHOW_HELP_DOCUMENT,
             ID_ABOUT_MENU,
             ID_FIRMWARE_INFO,
             ID_PIN_INFO,
