@@ -1,5 +1,5 @@
 /*
- * (c) 2007-2008, Bernhard Walle <bernhard.walle@gmx.de>
+ * (c) 2007-2010, Bernhard Walle <bernhard@bwalle.de>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ string wordwrap(const string &text, ssize_t margins)
     int curline = 0;
 
     while (ss >> s) {
-        if ((margins < 0) || (curline + s.size() + 1 < margins)) {
+        if ((margins < 0) || (curline + int(s.size()) + 1 < margins)) {
             if (curline != 0) {
                 ret += " ";
                 curline++;
